@@ -62,7 +62,7 @@ class Application(InteractionLayer):
     def preferences(self, v):
         self.set_preferences(prefs=v)
 
-    @Alias("setPreferences")
+    @Alias('setPreferences')
     def set_preferences(self, prefs=None, **kwargs):
         return self._client.app_set_preferences(prefs=prefs, **kwargs)
 
@@ -303,9 +303,8 @@ class Torrents(InteractionLayer):
         return self._client.torrents_add(urls=urls, torrent_files=torrent_files, save_path=save_path, cookie=cookie,
                                          category=category, is_skip_checking=is_skip_checking, is_paused=is_paused,
                                          is_root_folder=is_root_folder, rename=rename, upload_limit=upload_limit,
-                                         download_limit=download_limit,
+                                         download_limit=download_limit, is_sequential_download=is_sequential_download,
                                          use_auto_torrent_management=use_auto_torrent_management,
-                                         is_sequential_download=is_sequential_download,
                                          is_first_last_piece_priority=is_first_last_piece_priority, **kwargs)
 
     class _ActionForAllTorrents(InteractionLayer):
@@ -494,6 +493,10 @@ class RSS(InteractionLayer):
     def refresh_item(self, item_path=None):
         return self._client.rss_refresh_item(item_path=item_path)
 
+    @Alias('markAsRead')
+    def mark_as_read(self, item_path=None, article_id=None, **kwargs):
+        return self._client.rss_mark_as_read(item_path=item_path, article_id=article_id, **kwargs)
+
     @Alias('setRule')
     def set_rule(self, rule_name=None, rule_def=None, **kwargs):
         return self._client.rss_set_rule(rule_name=rule_name, rule_def=rule_def, **kwargs)
@@ -510,6 +513,10 @@ class RSS(InteractionLayer):
     def rules(self):
         return self._client.rss_rules()
 
+    @Alias('matchingArticles')
+    def matching_articles(self, rule_name=None, **kwargs):
+        return self._client.rss_matching_articles(rule_name=rule_name, **kwargs)
+
     class _Items(InteractionLayer):
         def __call__(self, include_feed_data=None, **kwargs):
             return self._client.rss_items(include_feed_data=include_feed_data, **kwargs)
