@@ -29,7 +29,7 @@ class RSSMixIn(RequestMixIn):
         :return: None
         """
         data = {'path': folder_path}
-        self._post(_name=APINames.RSS, _method='addFolder', data=data, **kwargs)
+        return self._post(_name=APINames.RSS, _method='addFolder', data=data, **kwargs)
 
     @Alias('rss_addFeed')
     @login_required
@@ -46,7 +46,7 @@ class RSSMixIn(RequestMixIn):
         """
         data = {'url': url,
                 'path': item_path}
-        self._post(_name=APINames.RSS, _method='addFeed', data=data, **kwargs)
+        return self._post(_name=APINames.RSS, _method='addFeed', data=data, **kwargs)
 
     @Alias('rss_removeItem')
     @login_required
@@ -63,7 +63,7 @@ class RSSMixIn(RequestMixIn):
         :return: None
         """
         data = {'path': item_path}
-        self._post(_name=APINames.RSS, _method='removeItem', data=data, **kwargs)
+        return self._post(_name=APINames.RSS, _method='removeItem', data=data, **kwargs)
 
     @Alias('rss_moveItem')
     @login_required
@@ -80,7 +80,7 @@ class RSSMixIn(RequestMixIn):
         """
         data = {'itemPath': orig_item_path,
                 'destPath': new_item_path}
-        self._post(_name=APINames.RSS, _method='moveItem', data=data, **kwargs)
+        return self._post(_name=APINames.RSS, _method='moveItem', data=data, **kwargs)
 
     @response_json(RSSitemsDictionary)
     @login_required
@@ -95,7 +95,7 @@ class RSSMixIn(RequestMixIn):
         return self._get(_name=APINames.RSS, _method='items', params=params, **kwargs)
 
     @version_implemented('2.2', 'rss/refreshItem')
-    @Alias("rss_refreshItem")
+    @Alias('rss_refreshItem')
     @login_required
     def rss_refresh_item(self, item_path=None, **kwargs):
         """
@@ -108,7 +108,25 @@ class RSSMixIn(RequestMixIn):
         from qbittorrentapi.helpers import is_version_less_than
         if is_version_less_than('v4.1.7', self.app_version(), False):
             params = {"itemPath": item_path}
-            self._get(_name=APINames.RSS, _method="refreshItem", params=params, **kwargs)
+            return self._get(_name=APINames.RSS, _method='refreshItem', params=params, **kwargs)
+
+    @version_implemented('2.5.1', 'rss/markAsRead')
+    @Alias('rss_markAsRead')
+    @login_required
+    def rss_mark_as_read(self, item_path=None, article_id=None, **kwargs):
+        """
+        Mark RSS article as read. If article ID is not provider, the entire feed is marked as read. (alias: rss_markAsRead)
+
+        Exceptions:
+            NotFound404Error
+
+        :param item_path: path to item to be refreshed (e.g. Folder\Subfolder\ItemName)
+        :param article_id: article ID from rss_items()
+        :return: None
+        """
+        data = {'itemPath': item_path,
+                'articleId': article_id}
+        return self._post(_name=APINames.RSS, _method='markAsRead', data=data, **kwargs)
 
     @Alias('rss_setRule')
     @login_required
@@ -123,7 +141,7 @@ class RSSMixIn(RequestMixIn):
         """
         data = {'ruleName': rule_name,
                 'ruleDef': dumps(rule_def)}
-        self._post(_name=APINames.RSS, _method='setRule', data=data, **kwargs)
+        return self._post(_name=APINames.RSS, _method='setRule', data=data, **kwargs)
 
     @Alias('rss_renameRule')
     @login_required
@@ -137,7 +155,7 @@ class RSSMixIn(RequestMixIn):
         """
         data = {'ruleName': orig_rule_name,
                 'newRuleName': new_rule_name}
-        self._post(_name=APINames.RSS, _method='renameRule', data=data, **kwargs)
+        return self._post(_name=APINames.RSS, _method='renameRule', data=data, **kwargs)
 
     @Alias('rss_removeRule')
     @login_required
@@ -149,7 +167,7 @@ class RSSMixIn(RequestMixIn):
         :return: None
         """
         data = {'ruleName': rule_name}
-        self._post(_name=APINames.RSS, _method='removeRule', data=data, **kwargs)
+        return self._post(_name=APINames.RSS, _method='removeRule', data=data, **kwargs)
 
     @response_json(RSSRulesDictionary)
     @login_required
@@ -160,3 +178,19 @@ class RSSMixIn(RequestMixIn):
         :return: None
         """
         return self._get(_name=APINames.RSS, _method='rules', **kwargs)
+
+    @version_implemented('2.5.1', 'rss/matchingArticles')
+    @Alias('rss_matchingArticles')
+    @response_json(RSSitemsDictionary)
+    @login_required
+    def rss_matching_articles(self, rule_name=None, **kwargs):
+        """
+        Fetch all articles matching a rule. (alias: rss_matchingArticles)
+
+        Exceptions:
+
+        :param rule_name: Name of rule to return matching articles
+        :return
+        """
+        data = {'ruleName': rule_name}
+        return self._post(_name=APINames.RSS, _method='matchingArticles', data=data, **kwargs)
